clear all

use "Blanco_Dalton_Vargas final dataset.dta"

set more off

*log using Blanco_Dalton_Vargas_replication, replace

**************************************************************************
* Blanco, Dalton, Vargas (2016) "Does the Unemployment Benefit Institution 
* affect the Productivity of Workers? Evidence from the Field" Management Science
*************************************************************************

********************************************************
* REPLICATION DO FILE 
********************************************************

********************************************************
******Some key variables********************************
********************************************************

*We start with the code for some key variables that are used several times 
*in the analysis

*Subsample of dropouts (for Tables 1, C.1 and E.5)
sort id_0 dia
gen condicion_temp=condicion_
replace condicion_temp=10 if condicion_==2
replace condicion_temp=0 if condicion_==.
bys id_0: egen max_temp=max(condicion_temp)
gen dropout=(max_temp==10)
drop condicion_temp max_temp
la var dropout "=1 if subject dropped out at any point in the experiment"

*Subsample of returners and dummy for return day (Tables 5, D.2 and E.6)
sort id_0 dia
gen return_day=0
bys id_0: replace return_day=1 if condicion_==1 & condicion_[_n-1]==0
bys id_0: egen returner=max(return_day)
la var returner "=1 for subject who lost his/her job and came back"
la var return_day "=1 for day in which a returner comes back"

*Subsample of always employed (Tables 5, 6, D.2 and E.6)
sort id_0 dia
gen condicion_temp=condicion_
replace condicion_temp=0 if condicion_==2
replace condicion_temp=1 if condicion_==3
bys id_0: egen sum_cond_temp=sum(condicion_temp)
gen always_emp=(sum_cond_temp==8)
la var always_emp "subsample of always employed"
drop condicion_temp sum_cond_temp

*Subsample of always unemployed (Table 6)
gen condicion_temp=condicion_
replace condicion_temp=0 if (dia==1 & condicion_!=2)
replace condicion_temp=0 if (dia==8 & condicion_!=2)
replace condicion_temp=0 if condicion_==3
bys id_0: egen sum_cond_temp=sum(condicion_temp)
gen always_unemp=(sum_cond_temp==0)
la var always_unemp "subsample of always unemployed"
drop condicion_temp sum_cond_temp

*Interaction between University A and UBI stage (Tables 4, 5, 6, E.1, E.3, E.4, E.5 and E.6)
gen interaccion=universidad*experimento 
la var interaccion "interaction between Uni A and UBI stage"

*Time-varying group size (Tables 4, 5, 6, E.1, E.3, E.4, E.5 and E.6)
gen condicion_temp=condicion_
replace condicion_temp=0 if condicion_!=1
bys grupo dia: egen group_size=sum(condicion_temp)
drop condicion_temp
la var group_size "Time-varying number of coder per group"

*Log productivity (Tables 4 and D.1)
gen log_productividad_=log(1+productividad_)
la var log_productividad_ "log of productivity"

*Change in self esteem
sort id_0 dia
gen temp=0
replace temp=autoestima_ if dia==0
bys id_0: egen initial_esteem=max(temp)
gen change_esteem=autoestima_-initial_esteem if dia==6
drop temp initial_esteem
la var change_esteem "Change in self-esteem from start to end of experiment"


*************************************************************************
*************************************************************************
*TABLE 1: Baseline sample differences across universities and treatments*
*************************************************************************
*************************************************************************

***Panel A***
*(to check the balance we focus on the cross-section of subjects and on those
*who actually started working -there are some who dropped out on day 1 and only
*went to the induction day-. Hence the condition on dia==1 &condicion_!=2)

**Blance in gender

*within University A (across comparison and UBI)
ttest genero if universidad==1 & dia==1 & condicion_!=2, by(baseline)
tab genero baseline if universidad==1 & dia==1 & condicion_!=2, chi2

*within University B (across comparison and UBI)
ttest genero if universidad==0 & dia==1 & condicion_!=2, by(baseline)
tab genero baseline if universidad==0 & dia==1 & condicion_!=2, chi2

*within Comparison (across universities)
ttest genero if baseline==1 & dia==1 & condicion_!=2, by(universidad)
tab genero universidad if baseline==1 & dia==1 & condicion_!=2, chi2

*within UBI (across universities)
ttest genero if baseline==0 & dia==1 & condicion_!=2, by(universidad)
tab genero universidad if baseline==0 & dia==1 & condicion_!=2, chi2


**Balance in age

*within University A (across comparison and UBI)
ttest edad if universidad==1 & dia==1 & condicion_!=2, by(baseline)

*within University B (across comparison and UBI)
ttest edad if universidad==0 & dia==1 & condicion_!=2, by(baseline)

*within Comparison (across universities)
ttest edad if baseline==1 & dia==1 & condicion_!=2, by(universidad)

*within UBI (across universities)
ttest edad if baseline==0 & dia==1 & condicion_!=2, by(universidad)


**Balance in socioeconomic status

*within University A (across comparison and UBI)
ttest estrato if universidad==1 & dia==1 & condicion_!=2, by(baseline)
tab estrato baseline if universidad==1 & dia==1 & condicion_!=2, exact

*within University B (across comparison and UBI)
ttest estrato if universidad==0 & dia==1 & condicion_!=2, by(baseline)
tab estrato baseline if universidad==0 & dia==1 & condicion_!=2, exact

*within Comparison (across universities)
ttest estrato if baseline==1 & dia==1 & condicion_!=2, by(universidad)
tab estrato universidad if baseline==1 & dia==1 & condicion_!=2, exact

*within UBI (across universities)
ttest estrato if baseline==0 & dia==1 & condicion_!=2, by(universidad)
tab estrato universidad if baseline==0 & dia==1 & condicion_!=2, exact


**Balance in Average GPA

*within University A (across comparison and UBI)
ttest promedio if universidad==1 & dia==1 & condicion_!=2, by(baseline)

*within University B (across comparison and UBI)
ttest promedio if universidad==0 & dia==1 & condicion_!=2, by(baseline)

*within Comparison (across universities)
ttest promedio if baseline==1 & dia==1 & condicion_!=2, by(universidad)

*within UBI (across universities)
ttest promedio if baseline==0 & dia==1 & condicion_!=2, by(universidad)


**Balance in whether subject is currently working

*within University A (across comparison and UBI)
ttest trabaja if universidad==1 & dia==1 & condicion_!=2, by(baseline)
tab trabaja baseline if universidad==1 & dia==1 & condicion_!=2, chi2

*within University B (across comparison and UBI)
ttest trabaja if universidad==0 & dia==1 & condicion_!=2, by(baseline)
tab trabaja baseline if universidad==0 & dia==1 & condicion_!=2, chi2

*within Comparison (across universities)
ttest trabaja if baseline==1 & dia==1 & condicion_!=2, by(universidad)
tab trabaja universidad if baseline==1 & dia==1 & condicion_!=2, chi2

*within UBI (across universities)
ttest trabaja if baseline==0 & dia==1 & condicion_!=2, by(universidad)
tab trabaja universidad if baseline==0 & dia==1 & condicion_!=2, chi2


**Balance in whether major is economics-related

*within University A (across comparison and UBI)
ttest carrera_dummy if universidad==1 & dia==1 & condicion_!=2, by(baseline)
tab carrera_dummy baseline if universidad==1 & dia==1 & condicion_!=2, chi2

*within University B (across comparison and UBI)
ttest carrera_dummy if universidad==0 & dia==1 & condicion_!=2, by(baseline)
tab carrera_dummy baseline if universidad==0 & dia==1 & condicion_!=2, chi2

*within Comparison (across universities)
ttest carrera_dummy if baseline==1 & dia==1 & condicion_!=2, by(universidad)
tab carrera_dummy universidad if baseline==1 & dia==1 & condicion_!=2, chi2

*within UBI (across universities)
ttest carrera_dummy if baseline==0 & dia==1 & condicion_!=2, by(universidad)
tab carrera_dummy universidad if baseline==0 & dia==1 & condicion_!=2, chi2


***PANEL B***

**Balance in initial self-esteem
*(initial self-esteem is measured on induction day prior to any work being
*carried on. However, as in Panel A, since some subjects dropped out right
* after the induction -and hence are not part of our sample even if we have
* their initial self-esteem, we need to drop them out. This is done first and
* then we check balance in self-esteem)

preserve
gen condicion_temp=condicion_
replace condicion_temp=10 if condicion_==2 & dia==1
replace condicion_temp=0 if condicion_==.
bys id_0:egen drop_these_subjects=max(condicion_temp)
drop if drop_these_subjects==10 
drop condicion_temp drop_these_subjects

*within University A (across comparison and UBI)
ttest autoestima_ if universidad==1 & dia==0, by(baseline)

*within University B (across comparison and UBI)
ttest autoestima_ if universidad==0 & dia==0, by(baseline)

*within Comparison (across universities)
ttest autoestima_ if baseline==1 & dia==0, by(universidad)

*within UBI (across universities)
ttest autoestima_ if baseline==0 & dia==0, by(universidad)
restore

**Balance in initial Job satisfaction

*within University A (across comparison and UBI)
ttest job_satisf_ if universidad==1 & dia==1 & condicion_!=2, by(baseline)

*within University B (across comparison and UBI)
ttest job_satisf_ if universidad==0 & dia==1 & condicion_!=2, by(baseline)

*within Comparison (across universities)
ttest job_satisf_ if baseline==1 & dia==1 & condicion_!=2, by(universidad)

*within UBI (across universities)
ttest job_satisf_ if baseline==0 & dia==1 & condicion_!=2, by(universidad)


***PANEL C***

**Balance on average intial productivity (all sample)

*within University A (across comparison and UBI)
ttest productividad_ if universidad==1 & dia==1 & condicion_!=2, by(baseline)

*within University B (across comparison and UBI)
ttest productividad_ if universidad==0 & dia==1 & condicion_!=2, by(baseline)

*within Comparison (across universities)
ttest productividad_ if baseline==1 & dia==1 & condicion_!=2, by(universidad)

*within UBI (across universities)
ttest productividad_ if baseline==0 & dia==1 & condicion_!=2, by(universidad)


**Balance on average intial productivity (dropouts)

*within University A (across comparison and UBI)
ttest productividad_ if universidad==1 & dropout==1 & dia==1, by(baseline)

*within University B (across comparison and UBI)
ttest productividad_ if universidad==0 & dropout==1 & dia==1, by(baseline)

*within Comparison (across universities)
ttest productividad_ if baseline==1 & dropout==1 & dia==1, by(universidad)

*within UBI (across universities)
ttest productividad_ if baseline==0 & dropout==1 & dia==1, by(universidad)


**Balance on average intial productivity (finalizers)

*within University A (across comparison and UBI)
ttest productividad_ if universidad==1 & dropout==0 & dia==1, by(baseline)

*within University B (across comparison and UBI)
ttest productividad_ if universidad==0 & dropout==0 & dia==1, by(baseline)

*within Comparison (across universities)
ttest productividad_ if baseline==1 & dropout==0 & dia==1, by(universidad)

*within UBI (across universities)
ttest productividad_ if baseline==0 & dropout==0 & dia==1, by(universidad)
*restore


**Balance on the gap in intial productivity between dropouts and finalizers

*within University A and UBI
ttest productividad_ if baseline==0 & universidad==1 & dia==1, by (dropout)

*within University B and UBI
ttest productividad_ if baseline==0 & universidad==0 & dia==1, by (dropout)

*within University A and Comparison
ttest productividad_ if baseline==1 & universidad==1 & dia==1, by (dropout)

*within University B and Comparison
ttest productividad_ if baseline==1 & universidad==0 & dia==1, by (dropout)

*within University A (across comparison and UBI)
*(look only at the interaction coefficient of the following DD regression)
gen baselinexdropout =baseline*dropout
reg productividad_ baseline dropout baselinexdropout if universidad==1 & dia==1

*within University B (across comparison and UBI)
*(look only at the interaction coefficient of the following DD regression)
reg productividad_ baseline dropout baselinexdropout if universidad==0 & dia==1

*within Comparison (across universities)
*(look only at the interaction coefficient of the following DD regression)
gen universidadxdropout= universidad*dropout
reg productividad_ universidad dropout universidadxdropout if baseline==1 & dia==1

*within UBI (across universities)
*(look only at the interaction coefficient of the following DD regression)
reg productividad_ universidad dropout universidadxdropout if baseline==0 & dia==1
******************END TABLE 1 ******************************************************

*************************************************************************
*************************************************************************
*TABLE 3: Recruitment and Atrittion
*************************************************************************
*************************************************************************
**day 1
sum condicion_ if dia==1 & baseline==0 & universidad==0 & condicion_!=2
sum condicion_ if dia==1 & baseline==0 & universidad==1 & condicion_!=2
sum condicion_ if dia==1 & baseline==1 & universidad==0 & condicion_!=2
sum condicion_ if dia==1 & baseline==1 & universidad==1 & condicion_!=2
sum condicion_ if dia==1 & condicion_!=2

**day 8
sum condicion_ if dia==8 & baseline==0 & universidad==0 & condicion_!=2
sum condicion_ if dia==8 & baseline==0 & universidad==1 & condicion_!=2
sum condicion_ if dia==8 & baseline==1 & universidad==0 & condicion_!=2
sum condicion_ if dia==8 & baseline==1 & universidad==1 & condicion_!=2
sum condicion_ if dia==8 & condicion_!=2

*(Attrition rates computed by hand as percentual loss between days 1 and 8)
******************END TABLE 3 ******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE 4: The effect of unemployment benefit institutions on the productivity of workers 
***************************************************************************************************************************
***************************************************************************************************************************

*column 1
reg productividad_ universidad experimento interaccion if estrato!=. & trabaja!=., vce(cluster grupo)
*column 2
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size, vce(cluster grupo)
*column 3
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
*column 4
reg log_productividad_ universidad experimento interaccion if estrato!=. & trabaja!=., vce(cluster grupo)
*column 5 
xi: reg log_productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size, vce(cluster grupo)
*column 6
xi: reg log_productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
******************END TABLE 4 ******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE 5: The effect of unemployment benefit institutions on the productivity of workers 
*(Subsamples of returners and always employed)
***************************************************************************************************************************

*column 1
reg productividad_ universidad experimento interaccion if estrato!=. & trabaja!=. & return_day==1, vce(cluster grupo)
*column 2
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if return_day==1, vce(cluster grupo)
*column 3
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if return_day==1, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
*column 4
reg productividad_ universidad experimento interaccion if estrato!=. & trabaja!=. & always_emp==1, vce(cluster grupo)
*column 5
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if always_emp==1, vce(cluster grupo)
*column 6
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if always_emp==1, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
******************END TABLE 5******************************************************
  
***************************************************************************************************************************
***************************************************************************************************************************
*TABLE 6: The effect of unemployment benefit institutions on the change in self-esteem 
***************************************************************************************************************************
***************************************************************************************************************************

*column 1
reg change_esteem universidad experimento interaccion if estrato!=. & trabaja!=. & dia==6 & always_unemp==1, vce(cluster grupo)
*column 2
xi: reg change_esteem universidad experimento interaccion genero i.estrato edad trabaja group_size if dia==6 & always_unemp==1, vce(cluster grupo)
*column 3
xi: reg change_esteem universidad experimento interaccion genero i.estrato edad trabaja group_size if dia==6 & always_unemp==1, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
*column 4
reg change_esteem universidad experimento interaccion if estrato!=. & trabaja!=. & dia==6 & always_emp==1, vce(cluster grupo)
*column 5
xi: reg change_esteem universidad experimento interaccion genero i.estrato edad trabaja group_size if dia==6 & always_emp==1, vce(cluster grupo)
*column 6
xi: reg change_esteem universidad experimento interaccion genero i.estrato edad trabaja group_size if dia==6 & always_emp==1, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
******************END TABLE 6******************************************************

*************************************************************************
*************************************************************************
*FIGURE 1: Daily average productivity by treatment stage across universities
*************************************************************************
*************************************************************************

*Figure 1a: Comparison stage
bys dia: egen mean_prod_rosario = mean(productividad_) if universidad==1 & baseline==1
bys dia: egen mean_prod_andes = mean(productividad_) if universidad==0 & baseline==1
twoway (line mean_prod_rosario dia, color(black)) (line mean_prod_andes dia, lpattern(dash) color(black)) if baseline==1, /*ti("Control stage", color(black))*/ yscale(range(0 150)) ylabel(0(50)150) xscale(range(1 8)) xtitle("Working day") ytitle("Productivity") legend(order(1 "University A" 2 "University B")) graphregion(fcolor(white)) ylabel(, nogrid)
drop mean_prod_rosario mean_prod_andes

*Figure 1b: UBI stage
bys dia: egen mean_prod_rosario = mean(productividad_) if universidad==1 & baseline==0
bys dia: egen mean_prod_andes = mean(productividad_) if universidad==0 & baseline==0
twoway (line mean_prod_rosario dia, color(black)) (line mean_prod_andes dia, lpattern(dash) color(black)) if baseline==0, /*ti("Control stage", color(black))*/ yscale(range(0 150)) ylabel(0(50)150) xscale(range(1 8)) xtitle("Working day") ytitle("Productivity") legend(order(1 "University A" 2 "University B")) graphregion(fcolor(white)) ylabel(, nogrid)
drop mean_prod_rosario mean_prod_andes
******************END FIGURE 1******************************************************

*************************************************************************
*************************************************************************
*FIGURE 2: Daily average productivity by university across treatments
*************************************************************************
*************************************************************************

*Figure 2a: University A
bys dia: egen mean_prod_comp = mean(productividad_) if baseline==1 & universidad==1
bys dia: egen mean_prod_ubi = mean(productividad_) if baseline==0 & universidad==1
twoway (line mean_prod_comp dia, color(black)) (line mean_prod_ubi dia, lpattern(dash) color(black)) if universidad==1, /*ti("Control stage", color(black))*/ yscale(range(0 150)) ylabel(0(50)150) xscale(range(1 8)) xtitle("Working day") ytitle("Productivity") legend(order(1 "Comparison" 2 "Unconditional")) graphregion(fcolor(white)) ylabel(, nogrid)
drop mean_prod_comp mean_prod_ubi

*Figure 2b: University B
bys dia: egen mean_prod_comp = mean(productividad_) if baseline==1 & universidad==0
bys dia: egen mean_prod_ubi = mean(productividad_) if baseline==0 & universidad==0
twoway (line mean_prod_comp dia, color(black)) (line mean_prod_ubi dia, lpattern(dash) color(black)) if universidad==0, /*ti("Control stage", color(black))*/ yscale(range(0 150)) ylabel(0(50)150) xscale(range(1 8)) xtitle("Working day") ytitle("Productivity") legend(order(1 "Comparison" 2 "Conditional")) graphregion(fcolor(white)) ylabel(, nogrid)
drop mean_prod_comp mean_prod_ubi
******************END FIGURE 2******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE B.1: Description of groups
***************************************************************************************************************************
***************************************************************************************************************************

**Columns 2, 3 and 4
*(Look at the min=max of the sum of each variable to see which university,
*paper and treatment (whether comparison or UBI) corresponds to each one of the
*18 groups)

forvalues i = 1(1)18 {
	sum universidad espectador baseline if grupo==`i'
}

**Columns 5 and 6
*(Given the university, paper and treatment of each group, get the number of
*coders in days 1 and 8)

*Group 1
sum condicion_ if grupo==1 & universidad==1 & espectador==0 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==1 & universidad==1 & espectador==0 & baseline==0 & dia==8 & condicion_==1
*Group 2
sum condicion_ if grupo==2 & universidad==1 & espectador==1 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==2 & universidad==1 & espectador==1 & baseline==0 & dia==8 & condicion_==1
*Group 3
sum condicion_ if grupo==3 & universidad==1 & espectador==1 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==3 & universidad==1 & espectador==1 & baseline==0 & dia==8 & condicion_==1
*Group 4
sum condicion_ if grupo==4 & universidad==1 & espectador==0 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==4 & universidad==1 & espectador==0 & baseline==0 & dia==8 & condicion_==1
*Group 5
sum condicion_ if grupo==5 & universidad==0 & espectador==0 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==5 & universidad==0 & espectador==0 & baseline==0 & dia==8 & condicion_==1
*Group 6
sum condicion_ if grupo==6 & universidad==0 & espectador==1 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==6 & universidad==0 & espectador==1 & baseline==0 & dia==8 & condicion_==1
*Group 7
sum condicion_ if grupo==7 & universidad==0 & espectador==0 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==7 & universidad==0 & espectador==0 & baseline==0 & dia==8 & condicion_==1
*Group 8
sum condicion_ if grupo==8 & universidad==0 & espectador==1 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==8 & universidad==0 & espectador==1 & baseline==0 & dia==8 & condicion_==1
*Group 9
sum condicion_ if grupo==9 & universidad==0 & espectador==0 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==9 & universidad==0 & espectador==0 & baseline==0 & dia==8 & condicion_==1
*Group 10
sum condicion_ if grupo==10 & universidad==0 & espectador==1 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==10 & universidad==0 & espectador==1 & baseline==0 & dia==8 & condicion_==1
*Group 11
sum condicion_ if grupo==11 & universidad==0 & espectador==0 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==11 & universidad==0 & espectador==0 & baseline==0 & dia==8 & condicion_==1
*Group 12
sum condicion_ if grupo==12 & universidad==0 & espectador==1 & baseline==0 & dia==1 & condicion_==1
sum condicion_ if grupo==12 & universidad==0 & espectador==1 & baseline==0 & dia==8 & condicion_==1
*Group 13
sum condicion_ if grupo==13 & universidad==1 & espectador==0 & baseline==1 & dia==1 & condicion_==1
sum condicion_ if grupo==13 & universidad==1 & espectador==0 & baseline==1 & dia==8 & condicion_==1
*Group 14
sum condicion_ if grupo==14 & universidad==1 & espectador==0 & baseline==1 & dia==1 & condicion_==1
sum condicion_ if grupo==14 & universidad==1 & espectador==0 & baseline==1 & dia==8 & condicion_==1
*Group 15
sum condicion_ if grupo==15 & universidad==1 & espectador==1 & baseline==1 & dia==1 & condicion_==1
sum condicion_ if grupo==15 & universidad==1 & espectador==1 & baseline==1 & dia==8 & condicion_==1
*Group 16
sum condicion_ if grupo==16 & universidad==0 & espectador==0 & baseline==1 & dia==1 & condicion_==1
sum condicion_ if grupo==16 & universidad==0 & espectador==0 & baseline==1 & dia==8 & condicion_==1
*Group 17
sum condicion_ if grupo==17 & universidad==0 & espectador==0 & baseline==1 & dia==1 & condicion_==1
sum condicion_ if grupo==17 & universidad==0 & espectador==0 & baseline==1 & dia==8 & condicion_==1
*Group 18
sum condicion_ if grupo==18 & universidad==0 & espectador==1 & baseline==1 & dia==1 & condicion_==1
sum condicion_ if grupo==18 & universidad==0 & espectador==1 & baseline==1 & dia==8 & condicion_==1

**Column 7
*(Percentage dropouts computed manually from columns 5 and 6)
******************END TABLE B.1 ******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE B.2: Day by day sample composition
***************************************************************************************************************************
***************************************************************************************************************************

gen condicion_temp=condicion_
replace condicion_temp=-2 if condicion_==2

*Day 1
*productivity
sum productividad_ if dia==1 & baseline==0 & universidad==0 & condicion_temp>0
sum productividad_ if dia==1 & baseline==0 & universidad==1 & condicion_temp>0
sum productividad_ if dia==1 & baseline==1 & universidad==0 & condicion_temp>0
sum productividad_ if dia==1 & baseline==1 & universidad==1 & condicion_temp>0
*employed
sum condicion_ if dia==1 & baseline==0 & universidad==0 & condicion_temp>0
sum condicion_ if dia==1 & baseline==0 & universidad==1 & condicion_temp>0
sum condicion_ if dia==1 & baseline==1 & universidad==0 & condicion_temp>0
sum condicion_ if dia==1 & baseline==1 & universidad==1 & condicion_temp>0

*Day 2
*employed
sum condicion_ if dia==2 & baseline==0 & universidad==0 & condicion_temp>0
sum condicion_ if dia==2 & baseline==0 & universidad==1 & condicion_temp>0
sum condicion_ if dia==2 & baseline==1 & universidad==0 & condicion_temp>0
sum condicion_ if dia==2 & baseline==1 & universidad==1 & condicion_temp>0
*unemployed
sum condicion_ if dia==2 & baseline==0 & universidad==0 & condicion_temp==0
sum condicion_ if dia==2 & baseline==0 & universidad==1 & condicion_temp==0
sum condicion_ if dia==2 & baseline==1 & universidad==0 & condicion_temp==0
sum condicion_ if dia==2 & baseline==1 & universidad==1 & condicion_temp==0
*(dropouts are the residual relative to those active on previos day)

*Day 3
*employed
sum condicion_ if dia==3 & baseline==0 & universidad==0 & condicion_temp>0
sum condicion_ if dia==3 & baseline==0 & universidad==1 & condicion_temp>0
sum condicion_ if dia==3 & baseline==1 & universidad==0 & condicion_temp>0
sum condicion_ if dia==3 & baseline==1 & universidad==1 & condicion_temp>0
*unemployed
sum condicion_ if dia==3 & baseline==0 & universidad==0 & condicion_temp==0
sum condicion_ if dia==3 & baseline==0 & universidad==1 & condicion_temp==0
sum condicion_ if dia==3 & baseline==1 & universidad==0 & condicion_temp==0
sum condicion_ if dia==3 & baseline==1 & universidad==1 & condicion_temp==0

*Day 4
*employed
sum condicion_ if dia==4 & baseline==0 & universidad==0 & condicion_temp>0
sum condicion_ if dia==4 & baseline==0 & universidad==1 & condicion_temp>0
sum condicion_ if dia==4 & baseline==1 & universidad==0 & condicion_temp>0
sum condicion_ if dia==4 & baseline==1 & universidad==1 & condicion_temp>0
*unemployed
sum condicion_ if dia==4 & baseline==0 & universidad==0 & condicion_temp==0
sum condicion_ if dia==4 & baseline==0 & universidad==1 & condicion_temp==0
sum condicion_ if dia==4 & baseline==1 & universidad==0 & condicion_temp==0
sum condicion_ if dia==4 & baseline==1 & universidad==1 & condicion_temp==0

*Day 5
*employed
sum condicion_ if dia==5 & baseline==0 & universidad==0 & condicion_temp>0
sum condicion_ if dia==5 & baseline==0 & universidad==1 & condicion_temp>0
sum condicion_ if dia==5 & baseline==1 & universidad==0 & condicion_temp>0
sum condicion_ if dia==5 & baseline==1 & universidad==1 & condicion_temp>0
*unemployed
sum condicion_ if dia==5 & baseline==0 & universidad==0 & condicion_temp==0
sum condicion_ if dia==5 & baseline==0 & universidad==1 & condicion_temp==0
sum condicion_ if dia==5 & baseline==1 & universidad==0 & condicion_temp==0
sum condicion_ if dia==5 & baseline==1 & universidad==1 & condicion_temp==0

*Day 6
*employed
sum condicion_ if dia==6 & baseline==0 & universidad==0 & condicion_temp>0
sum condicion_ if dia==6 & baseline==0 & universidad==1 & condicion_temp>0
sum condicion_ if dia==6 & baseline==1 & universidad==0 & condicion_temp>0
sum condicion_ if dia==6 & baseline==1 & universidad==1 & condicion_temp>0
*unemployed
sum condicion_ if dia==6 & baseline==0 & universidad==0 & condicion_temp==0
sum condicion_ if dia==6 & baseline==0 & universidad==1 & condicion_temp==0
sum condicion_ if dia==6 & baseline==1 & universidad==0 & condicion_temp==0
sum condicion_ if dia==6 & baseline==1 & universidad==1 & condicion_temp==0

*Day 7
*employed
sum condicion_ if dia==7 & baseline==0 & universidad==0 & condicion_temp>0
sum condicion_ if dia==7 & baseline==0 & universidad==1 & condicion_temp>0
sum condicion_ if dia==7 & baseline==1 & universidad==0 & condicion_temp>0
sum condicion_ if dia==7 & baseline==1 & universidad==1 & condicion_temp>0
*unemployed
sum condicion_ if dia==7 & baseline==0 & universidad==0 & condicion_temp==0
sum condicion_ if dia==7 & baseline==0 & universidad==1 & condicion_temp==0
sum condicion_ if dia==7 & baseline==1 & universidad==0 & condicion_temp==0
sum condicion_ if dia==7 & baseline==1 & universidad==1 & condicion_temp==0

*Day 8
*employed
sum condicion_ if dia==8 & baseline==0 & universidad==0 & condicion_temp>0
sum condicion_ if dia==8 & baseline==0 & universidad==1 & condicion_temp>0
sum condicion_ if dia==8 & baseline==1 & universidad==0 & condicion_temp>0
sum condicion_ if dia==8 & baseline==1 & universidad==1 & condicion_temp>0
*unemployed
sum condicion_ if dia==8 & baseline==0 & universidad==0 & condicion_temp==0
sum condicion_ if dia==8 & baseline==0 & universidad==1 & condicion_temp==0
sum condicion_ if dia==8 & baseline==1 & universidad==0 & condicion_temp==0
sum condicion_ if dia==8 & baseline==1 & universidad==1 & condicion_temp==0

drop condicion_temp
******************END TABLE B.2 ******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE C.1: Baseline sample differences across universities and treatments-- Dropouts
***************************************************************************************************************************
***************************************************************************************************************************

***Panel A***
*(For comparability with Table 1 we focus on those who dropped out after day 1)

**Blance in gender

*within University A (across comparison and UBI)
ttest genero if universidad==1 & dia==1 & condicion_!=2 & dropout==1, by(baseline)
tab genero baseline if universidad==1 & dia==1 & condicion_!=2 & dropout==1, chi2

*within University B (across comparison and UBI)
ttest genero if universidad==0 & dia==1 & condicion_!=2 & dropout==1, by(baseline)
tab genero baseline if universidad==0 & dia==1 & condicion_!=2 & dropout==1, chi2

*within Comparison (across universities)
ttest genero if baseline==1 & dia==1 & condicion_!=2 & dropout==1, by(universidad)
tab genero universidad if baseline==1 & dia==1 & condicion_!=2 & dropout==1, chi2

*within UBI (across universities)
ttest genero if baseline==0 & dia==1 & condicion_!=2 & dropout==1, by(universidad)
tab genero universidad if baseline==0 & dia==1 & condicion_!=2 & dropout==1, chi2


**Balance in age

*within University A (across comparison and UBI)
ttest edad if universidad==1 & dia==1 & condicion_!=2 & dropout==1, by(baseline)

*within University B (across comparison and UBI)
ttest edad if universidad==0 & dia==1 & condicion_!=2 & dropout==1, by(baseline)

*within Comparison (across universities)
ttest edad if baseline==1 & dia==1 & condicion_!=2 & dropout==1, by(universidad)

*within UBI (across universities)
ttest edad if baseline==0 & dia==1 & condicion_!=2 & dropout==1, by(universidad)


**Balance in socioeconomic status

*within University A (across comparison and UBI)
ttest estrato if universidad==1 & dia==1 & condicion_!=2 & dropout==1, by(baseline)
tab estrato baseline if universidad==1 & dia==1 & condicion_!=2 & dropout==1, exact

*within University B (across comparison and UBI)
ttest estrato if universidad==0 & dia==1 & condicion_!=2 & dropout==1, by(baseline)
tab estrato baseline if universidad==0 & dia==1 & condicion_!=2 & dropout==1, exact

*within Comparison (across universities)
ttest estrato if baseline==1 & dia==1 & condicion_!=2 & dropout==1, by(universidad)
tab estrato universidad if baseline==1 & dia==1 & condicion_!=2 & dropout==1, exact

*within UBI (across universities)
ttest estrato if baseline==0 & dia==1 & condicion_!=2 & dropout==1, by(universidad)
tab estrato universidad if baseline==0 & dia==1 & condicion_!=2 & dropout==1, exact


**Balance in Average GPA

*within University A (across comparison and UBI)
ttest promedio if universidad==1 & dia==1 & condicion_!=2 & dropout==1, by(baseline)

*within University B (across comparison and UBI)
ttest promedio if universidad==0 & dia==1 & condicion_!=2 & dropout==1, by(baseline)

*within Comparison (across universities)
ttest promedio if baseline==1 & dia==1 & condicion_!=2 & dropout==1, by(universidad)

*within UBI (across universities)
ttest promedio if baseline==0 & dia==1 & condicion_!=2 & dropout==1, by(universidad)


**Balance in whether subject is currently working

*within University A (across comparison and UBI)
ttest trabaja if universidad==1 & dia==1 & condicion_!=2 & dropout==1, by(baseline)
tab trabaja baseline if universidad==1 & dia==1 & condicion_!=2 & dropout==1, chi2

*within University B (across comparison and UBI)
ttest trabaja if universidad==0 & dia==1 & condicion_!=2 & dropout==1, by(baseline)
tab trabaja baseline if universidad==0 & dia==1 & condicion_!=2 & dropout==1, chi2

*within Comparison (across universities)
ttest trabaja if baseline==1 & dia==1 & condicion_!=2 & dropout==1, by(universidad)
tab trabaja universidad if baseline==1 & dia==1 & condicion_!=2 & dropout==1, chi2

*within UBI (across universities)
ttest trabaja if baseline==0 & dia==1 & condicion_!=2 & dropout==1, by(universidad)
tab trabaja universidad if baseline==0 & dia==1 & condicion_!=2 & dropout==1, chi2


**Balance in whether major is economics-related

*within University A (across comparison and UBI)
ttest carrera_dummy if universidad==1 & dia==1 & condicion_!=2 & dropout==1, by(baseline)
tab carrera_dummy baseline if universidad==1 & dia==1 & condicion_!=2 & dropout==1, chi2

*within University B (across comparison and UBI)
ttest carrera_dummy if universidad==0 & dia==1 & condicion_!=2 & dropout==1, by(baseline)
tab carrera_dummy baseline if universidad==0 & dia==1 & condicion_!=2 & dropout==1, chi2

*within Comparison (across universities)
ttest carrera_dummy if baseline==1 & dia==1 & condicion_!=2 & dropout==1, by(universidad)
tab carrera_dummy universidad if baseline==1 & dia==1 & condicion_!=2 & dropout==1, chi2

*within UBI (across universities)
ttest carrera_dummy if baseline==0 & dia==1 & condicion_!=2 & dropout==1, by(universidad)
tab carrera_dummy universidad if baseline==0 & dia==1 & condicion_!=2 & dropout==1, chi2


***PANEL B***

**Balance in initial self-esteem
*(For comparability with Table 1 we focus on those who dropped out after day 1)

preserve
gen condicion_temp=condicion_
replace condicion_temp=10 if condicion_==2 & dia==1
replace condicion_temp=0 if condicion_==.
bys id_0:egen drop_these_subjects=max(condicion_temp)
drop if drop_these_subjects==10 
drop condicion_temp drop_these_subjects

*within University A (across comparison and UBI)
ttest autoestima_ if universidad==1 & dia==0 & dropout==1, by(baseline)

*within University B (across comparison and UBI)
ttest autoestima_ if universidad==0 & dia==0 & dropout==1, by(baseline)

*within Comparison (across universities)
ttest autoestima_ if baseline==1 & dia==0 & dropout==1, by(universidad)

*within UBI (across universities)
ttest autoestima_ if baseline==0 & dia==0 & dropout==1, by(universidad)
restore

**Balance in initial Job satisfaction

*within University A (across comparison and UBI)
ttest job_satisf_ if universidad==1 & dia==1 & condicion_!=2 & dropout==1, by(baseline)

*within University B (across comparison and UBI)
ttest job_satisf_ if universidad==0 & dia==1 & condicion_!=2 & dropout==1, by(baseline)

*within Comparison (across universities)
ttest job_satisf_ if baseline==1 & dia==1 & condicion_!=2 & dropout==1, by(universidad)

*within UBI (across universities)
ttest job_satisf_ if baseline==0 & dia==1 & condicion_!=2 & dropout==1, by(universidad)


***PANEL C***
**Balance on average intial productivity

*within University A (across comparison and UBI)
ttest productividad_ if universidad==1 & dropout==1 & dia==1, by(baseline)

*within University B (across comparison and UBI)
ttest productividad_ if universidad==0 & dropout==1 & dia==1, by(baseline)

*within Comparison (across universities)
ttest productividad_ if baseline==1 & dropout==1 & dia==1, by(universidad)

*within UBI (across universities)
ttest productividad_ if baseline==0 & dropout==1 & dia==1, by(universidad)


**Balance on the variance of intial productivity

*within University A (across comparison and UBI)
robvar productividad_ if universidad==1 & dropout==1 & dia==1, by(baseline)

*within University B (across comparison and UBI)
robvar productividad_ if universidad==0 & dropout==1 & dia==1, by(baseline)

*within Comparison (across universities)
robvar productividad_ if baseline==1 & dropout==1 & dia==1, by(universidad)

*within UBI (across universities)
robvar productividad_ if baseline==0 & dropout==1 & dia==1, by(universidad)
******************END TABLE C.1 ******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE D.1: The effect of unemployment benefit institutions on the productivity of workers correcting for
* multiple hypothesis testing
***************************************************************************************************************************
***************************************************************************************************************************

gen treat=0
replace treat=1 if baseline==0 & universidad==0
replace treat=2 if baseline==0 & universidad==1
la var treat "0 baseline, 1 workfare, 2 welfare"

listetal2015 productividad_ log_productividad_, treatment(treat) combo("pairwise")

******************END TABLE D.1 ******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE D.2: The effect of unemployment benefit institutions on the productivity of workers correcting for 
* multiple hypothesis testing (Subsamples of returners and always employed)
***************************************************************************************************************************
***************************************************************************************************************************

gen groupid = (return_day==1) + (always_emp)*2
replace groupid = . if groupid == 0
la var groupid "1 returners on the return day, 2 always employed"

listetal2015 productividad_, treatment(treat) subgroup(groupid) combo("pairwise")

******************END TABLE D.2 ******************************************************

***********************************************************************************
***********************************************************************************
***SEE TABLES E.1 and E.2 at the end of the do file
***********************************************************************************
***********************************************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE E.3: Determinants of attrition and differential attrition across treatments
***************************************************************************************************************************
***************************************************************************************************************************

preserve
drop if condicion_==3

gen attrition=(condicion_==2)
*dependent var is the decision of dropping out

sort id_0 dia

bys id_0: gen unemp_yesterday=(condicion_[_n-1]==0)
la var unemp_yesterday "=1 if unemployed previous day"

gen days_unemployed=0

bys id_0: replace days_unemployed=1 if condicion_[_n-1]==0 & condicion_[_n-2]==1
bys id_0: replace days_unemployed=2 if condicion_[_n-1]==0 & condicion_[_n-2]==0 & condicion_[_n-3]==1
bys id_0: replace days_unemployed=3 if condicion_[_n-1]==0 & condicion_[_n-2]==0 & condicion_[_n-3]==0 & condicion_[_n-4]==1
bys id_0: replace days_unemployed=4 if condicion_[_n-1]==0 & condicion_[_n-2]==0 & condicion_[_n-3]==0 & condicion_[_n-4]==0 & condicion_[_n-5]==1
bys id_0: replace days_unemployed=5 if condicion_[_n-1]==0 & condicion_[_n-2]==0 & condicion_[_n-3]==0 & condicion_[_n-4]==0 & condicion_[_n-5]==0 & condicion_[_n-6]==1
bys id_0: replace days_unemployed=6 if condicion_[_n-1]==0 & condicion_[_n-2]==0 & condicion_[_n-3]==0 & condicion_[_n-4]==0 & condicion_[_n-5]==0 & condicion_[_n-6]==0 & condicion_[_n-7]==1
la var days_unemployed "unemployment spell at the time of dropping out"

bys id_0: gen old_dropper=(condicion_[_n-1]==2)

drop if old_dropper==1

bys id_0: gen failed_application=(aplico_[_n-1]==1 & condicion_[_n-1]==0)
la var failed_applicatio "=1 if day before applied for an opoening but was rejected"

gen prod_day1=0
replace prod_day1=productividad_ if dia==1
bys id_0: egen prod_ini=max(prod_day1)
la var prod_ini "Day 1 productivity"

keep if dia>2

*column 1
reg attrition universidad experimento interaccion if estrato!=. & trabaja!=., vce(cluster grupo)
*column 2
reg attrition universidad experimento interaccion unemp_yesterday if estrato!=. & trabaja!=., vce(cluster grupo)
*column 3
reg attrition universidad experimento interaccion unemp_yesterday days_unemployed if estrato!=. & trabaja!=., vce(cluster grupo)
*column 4
reg attrition universidad experimento interaccion unemp_yesterday days_unemployed failed_application if estrato!=. & trabaja!=., vce(cluster grupo)
*column 5
reg attrition universidad experimento interaccion unemp_yesterday days_unemployed failed_application prod_ini if estrato!=. & trabaja!=., vce(cluster grupo)
*column 6
xi: reg attrition universidad experimento interaccion unemp_yesterday days_unemployed failed_application prod_ini dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size, vce(cluster grupo)
*column 7
xi: reg attrition universidad experimento interaccion unemp_yesterday days_unemployed failed_application prod_ini dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
******************END TABLE E.3 ******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE E.4: Does experiencing unemployment affect attrition differentially across treatments?
***************************************************************************************************************************
***************************************************************************************************************************

gen unempyestxuni=unemp_yesterday*universidad
gen unempyestxexp=unemp_yesterday*experimento
gen unempyestxinter=unemp_yesterday*interaccion

*column 1
reg attrition universidad experimento interaccion unemp_yesterday unempyestxuni unempyestxexp unempyestxinter if estrato!=. & trabaja!=., vce(cluster grupo)
*column 2
xi: reg attrition universidad experimento interaccion unemp_yesterday unempyestxuni unempyestxexp unempyestxinter dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size, vce(cluster grupo)
*column 3
xi: reg attrition universidad experimento interaccion unemp_yesterday unempyestxuni unempyestxexp unempyestxinter dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
*column 4
xi: reg attrition universidad experimento interaccion dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size  if unemp_yesterday==1, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
*column 5
xi: reg attrition universidad experimento interaccion dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size  if unemp_yesterday==0, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
restore
******************END TABLE E.4 ******************************************************
  
*************************************************************************
*************************************************************************
*TABLE E.5: The effect of unemployment benefit institutions on the productivity
*of workers (Subsample of finalizers)
*************************************************************************
*************************************************************************

*column 1
reg productividad_ universidad experimento interaccion if estrato!=. & trabaja!=. & dropout==0, vce(cluster grupo)
*column 2
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if dropout==0, vce(cluster grupo)
*column 3
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if dropout==0, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
******************END TABLE E.5 ******************************************************

*************************************************************************
*************************************************************************
*TABLE E.6: The effect of treatments on selection into subsamples
*************************************************************************
*************************************************************************

*column 1
reg productividad_ universidad experimento interaccion if estrato!=. & trabaja!=. & returner==1 & dia==1, vce(cluster grupo)
*column 2
xi: reg productividad_ universidad experimento interaccion genero i.estrato edad trabaja group_size if returner==1  & dia==1, vce(cluster grupo)
*column 3
xi: reg productividad_ universidad experimento interaccion genero i.estrato edad trabaja group_size if returner==1  & dia==1, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
*column 4
reg productividad_ universidad experimento interaccion if estrato!=. & trabaja!=. & always_emp==1 & dia==1, vce(cluster grupo)
*column 5
xi: reg productividad_ universidad experimento interaccion genero i.estrato edad trabaja group_size if always_emp==1  & dia==1, vce(cluster grupo)
*column 6
xi: reg productividad_ universidad experimento interaccion genero i.estrato edad trabaja group_size if always_emp==1 & dia==1, vce(bootstrap, reps(1000) seed(4101) cluster(grupo) idcluster(bs_grupo) group(id_0))
******************END TABLE E.6 ******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE E.1: The effect of unemployment benefit institutions on the productivity of workers Balanced samples on covariates
* originally unbalanced
***************************************************************************************************************************
***************************************************************************************************************************

*This code does the following:
*For each one of the unbalanced characteristcis it generates 100 balanced random
*samples and runs the basic regression with controls on all the 100 balanced
*samples. Then it averages estimates and standard errors across the 100
*regressions. This is what is reported in the table in columns 2 to 5.
*Column 1 just reproduces columns 2 of Tale 4 as benchmark
*Colums 6 does the same procedure but balancing across all the unbalanced
*characteristcis at the same time.

*note: for the table presented in the paper this process was not done with ""set seed" and hence the coeffcients may differ slightly in any attempted replicatio

*1. Originally unbalanced attribute: Gender
set more off

forvalues i=1(1)100 { 
*This gets rid of the excess women in University A in the Comparison tretament
gen rand_R_cont_gen = runiform() if universidad==1 & baseline==1 & genero==1

sort rand_R_cont_gen

gen drop_gen=_n <= 17

*This gets rid of the excess women in University A in the UBI tretament
*becasuse of the loop this is repeated 100 timmes
*because of the random number generated, this creates 100 different balanced samples
gen rand_R_ubi_gen = runiform() if universidad==1 & baseline==0 & genero==1

sort rand_R_ubi_gen

replace drop_gen= 1 if _n <= 20

gen sample_gen_`i'=(drop_gen==0)

drop rand_R_cont_gen rand_R_ubi_gen drop_gen
}


*keep the ids of the 100 balanced samples and generate a databse with them
*which is then merged with the original base to produce 100 estimations balanced on gender
keep id_0 sample_gen_1-sample_gen_100

save "gender_samples.dta", replace

use "Blanco_Dalton_Vargas dataset.dta"

mmerge id_0 using "gender_samples.dta"


*Group size day by day
gen condicion2=condicion_
replace condicion2=0 if condicion_!=1
bys grupo dia: egen group_size=sum(condicion2)

set more off
forvalues i=1(1)100 { 
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if sample_gen_`i'==1, vce(cluster grupo)
} 

*2. Originally unbalanced attribute: Socioeconomic Straum

*The next bit does the same for socioeconomic stratum
*Here the code is a bit longer because to balance socioeconomic stratum need to
*in the comparison treatment get rid of individuals in strata 1 and 2
*(who do not have common support across the universities), get rid of 13(4) individuals
* of stratum 3(4) of Uni A, and get rid of 3(6) of stratum 5(6) of UniB.
*Then in the Ubi treatment some other dropping is necessary (see the code)

set more off
forvalues i=1(1)100 { 
gen drop_estrato=(estrato<3 & baseline==1)

gen rand_R_cont_estrato3 = runiform() if universidad==1 & baseline==1 & estrato==3

sort rand_R_cont_estrato3

replace drop_estrato=1 if _n <= 13

gen rand_R_cont_estrato4 = runiform() if universidad==1 & baseline==1 & estrato==4

sort rand_R_cont_estrato4

replace drop_estrato=1 if _n <= 3

gen rand_R_cont_estrato5 = runiform() if universidad==0 & baseline==1 & estrato==5

sort rand_R_cont_estrato5

replace drop_estrato=1 if _n <= 3

gen rand_R_cont_estrato6 = runiform() if universidad==0 & baseline==1 & estrato==6

sort rand_R_cont_estrato6

replace drop_estrato=1 if _n <= 6

*

gen rand_R_ubi_estrato2 = runiform() if universidad==1 & baseline==0 & estrato==2

sort rand_R_ubi_estrato2

replace drop_estrato=1 if _n <= 2

gen rand_R_ubi_estrato3 = runiform() if universidad==1 & baseline==0 & estrato==3

sort rand_R_ubi_estrato3

replace drop_estrato=1 if _n <= 1

gen rand_R_ubi_estrato4 = runiform() if universidad==0 & baseline==0 & estrato==4

sort rand_R_ubi_estrato4

replace drop_estrato=1 if _n <= 29

gen rand_R_ubi_estrato5 = runiform() if universidad==0 & baseline==0 & estrato==5

sort rand_R_ubi_estrato5

replace drop_estrato=1 if _n <= 26

gen rand_R_ubi_estrato6 = runiform() if universidad==0 & baseline==0 & estrato==6

sort rand_R_ubi_estrato6

replace drop_estrato=1 if _n <= 31


gen sample_estrato_`i'=(drop_estrato==0)

drop rand_R_* drop_estrato
}

keep id_0 sample_estrato_1-sample_estrato_100

save "estrato_samples.dta", replace

use "Blanco_Dalton_Vargas dataset.dta"

mmerge id_0 using "estrato_samples.dta"


*Group size day by day
gen condicion2=condicion_
replace condicion2=0 if condicion_!=1
bys grupo dia: egen group_size=sum(condicion2)

set more off
forvalues i=1(1)100 { 
set more off
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if sample_estrato_`i'==1, vce(cluster grupo)
} 

*3. Originally unbalanced attribute: Age

set more off
forvalues i=1(1)100 { 

gen rand_R_cont_age = runiform() if universidad==1 & baseline==1 & edad==24

sort rand_R_cont_age

gen drop_age=_n <= 1

gen sample_age_`i'=(drop_age==0)

drop rand_R_cont_age drop_age
}

keep id_0 sample_age_1-sample_age_100

save "age_samples.dta", replace

use "Blanco_Dalton_Vargas dataset.dta"

mmerge id_0 using "age_samples.dta"


*Group size day by day
gen condicion2=condicion_
replace condicion2=0 if condicion_!=1
bys grupo dia: egen group_size=sum(condicion2)

set more off
forvalues i=1(1)100 { 
set more off
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if sample_age_`i'==1, vce(cluster grupo)
} 


*4. Originally unbalanced attribute: Currently working

set more off
forvalues i=1(1)100 { 

gen rand_R_cont_trabaja = runiform() if universidad==0 & baseline==1 & trabaja==1

sort rand_R_cont_trabaja

gen drop_trabaja=_n <= 6

gen sample_trabaja_`i'=(drop_trabaja==0)

drop rand_R_cont_trabaja drop_trabaja
}
keep id_0 sample_trabaja_1-sample_trabaja_100

save "job_samples.dta", replace

use "Blanco_Dalton_Vargas dataset.dta"

mmerge id_0 using "job_samples.dta"


*Group size day by day
gen condicion2=condicion_
replace condicion2=0 if condicion_!=1
bys grupo dia: egen group_size=sum(condicion2)

set more off
forvalues i=1(1)100 { 
set more off
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if sample_trabaja_`i'==1, vce(cluster grupo)
} 


*****
*Balance sample across all characteristics at the same time
set more off

forvalues i=1(1)100 { 
gen rand_R_cont_gen = runiform() if universidad==1 & baseline==1 & genero==1

sort rand_R_cont_gen

gen drop_all=_n <= 17

gen rand_R_ubi_gen = runiform() if universidad==1 & baseline==0 & genero==1

sort rand_R_ubi_gen

replace drop_all= 1 if _n <= 20

***

replace drop_all=1 if estrato<3 & baseline==1

gen rand_R_cont_estrato3 = runiform() if universidad==1 & baseline==1 & estrato==3

sort rand_R_cont_estrato3

replace drop_all=1 if _n <= 13

gen rand_R_cont_estrato4 = runiform() if universidad==1 & baseline==1 & estrato==4

sort rand_R_cont_estrato4

replace drop_all=1 if _n <= 3

gen rand_R_cont_estrato5 = runiform() if universidad==0 & baseline==1 & estrato==5

sort rand_R_cont_estrato5

replace drop_all=1 if _n <= 3

gen rand_R_cont_estrato6 = runiform() if universidad==0 & baseline==1 & estrato==6

sort rand_R_cont_estrato6

replace drop_all=1 if _n <= 6


gen rand_R_ubi_estrato2 = runiform() if universidad==1 & baseline==0 & estrato==2

sort rand_R_ubi_estrato2

replace drop_all=1 if _n <= 2

gen rand_R_ubi_estrato3 = runiform() if universidad==1 & baseline==0 & estrato==3

sort rand_R_ubi_estrato3

replace drop_all=1 if _n <= 1

gen rand_R_ubi_estrato4 = runiform() if universidad==0 & baseline==0 & estrato==4

sort rand_R_ubi_estrato4

replace drop_all=1 if _n <= 29

gen rand_R_ubi_estrato5 = runiform() if universidad==0 & baseline==0 & estrato==5

sort rand_R_ubi_estrato5

replace drop_all=1 if _n <= 26

gen rand_R_ubi_estrato6 = runiform() if universidad==0 & baseline==0 & estrato==6

sort rand_R_ubi_estrato6

replace drop_all=1 if _n <= 31

*

gen rand_R_cont_age = runiform() if universidad==1 & baseline==1 & edad==24

sort rand_R_cont_age

replace drop_all=1 if _n <= 1

*

gen rand_R_cont_trabaja = runiform() if universidad==0 & baseline==1 & trabaja==1

sort rand_R_cont_trabaja

replace drop_all=1 if _n <= 6

*

gen sample_all_`i'=(drop_all==0)
drop rand_R_* drop_all
}

keep id_0 sample_all_1-sample_all_100

save "all_samples.dta", replace

use "Blanco_Dalton_Vargas dataset.dta"

mmerge id_0 using "all_samples.dta"


*Group size day by day
gen condicion2=condicion_
replace condicion2=0 if condicion_!=1
bys grupo dia: egen group_size=sum(condicion2)

set more off
forvalues i=1(1)100 { 
set more off
xi: reg productividad_ universidad experimento interaccion dia_2 dia_3 dia_4 dia_5 dia_6 dia_7 dia_8 genero i.estrato edad trabaja group_size if sample_all_`i'==1, vce(cluster grupo)
} 
******************END TABLE E.1 ******************************************************

***************************************************************************************************************************
***************************************************************************************************************************
*TABLE E.2: Baseline sample differences across universities and treatments
***************************************************************************************************************************
***************************************************************************************************************************

*This table shows that the subsamples created for Table E.1 solve the unbalance problem of Tables 1 and C.1
*NEW BALANCE TABLE

clear all 
use "Blanco_Dalton_Vargas dataset.dta"

*GENDER

gen rand_R_cont_gen = runiform() if universidad==1 & baseline==1 & genero==1

sort rand_R_cont_gen

gen drop_gen=_n <= 17

gen rand_R_ubi_gen = runiform() if universidad==1 & baseline==0 & genero==1

sort rand_R_ubi_gen

replace drop_gen= 1 if _n <= 20

gen sample_gen=(drop_gen==0)

keep if sample_gen==1

drop if (dia!=1 | condicion_==2)
ttest genero if universidad==1, by(baseline)
tab genero baseline if universidad==1, chi2

**diff within UAndes

ttest genero if universidad==0, by(baseline)
tab genero baseline if universidad==0, chi2

**diff within CONTROL
ttest genero if baseline==1, by(universidad)
tab genero universidad if baseline==1, chi2

**diff within TREATMENTS
ttest genero if baseline==0, by(universidad)
tab genero universidad if baseline==0, chi2

*AGE

replace condicion_=2 if id_0==388

drop if (dia!=1 | condicion_==2)

gen rand_R_cont_age = runiform() if universidad==1 & baseline==1 & edad==24

sort rand_R_cont_age

gen drop_age=_n <= 1

gen sample_age=(drop_age==0)

keep if sample_age==1

drop if (dia!=1 | condicion_==2)
ttest edad if universidad==1, by(baseline)

**diff within UAndes

ttest edad if universidad==0, by(baseline)

**diff within CONTROL
ttest edad if baseline==1, by(universidad)

**diff within TREATMENTS
ttest edad if baseline==0, by(universidad)

*ECOMIC STATUS

replace condicion_=2 if id_0==388

drop if (dia!=1 | condicion_==2)

gen drop_estrato=(estrato<3 & baseline==1)

gen rand_R_cont_estrato3 = runiform() if universidad==1 & baseline==1 & estrato==3

sort rand_R_cont_estrato3

replace drop_estrato=1 if _n <= 13

gen rand_R_cont_estrato4 = runiform() if universidad==1 & baseline==1 & estrato==4

sort rand_R_cont_estrato4

replace drop_estrato=1 if _n <= 3

gen rand_R_cont_estrato5 = runiform() if universidad==0 & baseline==1 & estrato==5

sort rand_R_cont_estrato5

replace drop_estrato=1 if _n <= 3

gen rand_R_cont_estrato6 = runiform() if universidad==0 & baseline==1 & estrato==6

sort rand_R_cont_estrato6

replace drop_estrato=1 if _n <= 6

*

gen rand_R_ubi_estrato2 = runiform() if universidad==1 & baseline==0 & estrato==2

sort rand_R_ubi_estrato2

replace drop_estrato=1 if _n <= 2

gen rand_R_ubi_estrato3 = runiform() if universidad==1 & baseline==0 & estrato==3

sort rand_R_ubi_estrato3

replace drop_estrato=1 if _n <= 1

gen rand_R_ubi_estrato4 = runiform() if universidad==0 & baseline==0 & estrato==4

sort rand_R_ubi_estrato4

replace drop_estrato=1 if _n <= 29

gen rand_R_ubi_estrato5 = runiform() if universidad==0 & baseline==0 & estrato==5

sort rand_R_ubi_estrato5

replace drop_estrato=1 if _n <= 26

gen rand_R_ubi_estrato6 = runiform() if universidad==0 & baseline==0 & estrato==6

sort rand_R_ubi_estrato6

replace drop_estrato=1 if _n <= 31


gen sample_estrato=(drop_estrato==0)

keep if sample_estrato==1

drop if (dia!=1 | condicion_==2)
ttest estrato if universidad==1, by(baseline)
tab estrato baseline if universidad==1, exact

**diff within UAndes

ttest estrato if universidad==0, by(baseline)
tab estrato baseline if universidad==0, exact

**diff within CONTROL
ttest estrato if baseline==1, by(universidad)
tab estrato universidad if baseline==1, exact

**diff within TREATMENTS
ttest estrato if baseline==0, by(universidad)
tab estrato universidad if baseline==0, exact

*Second JOB

replace condicion_=2 if id_0==388

drop if (dia!=1 | condicion_==2)

gen rand_R_cont_trabaja = runiform() if universidad==0 & baseline==1 & trabaja==1

sort rand_R_cont_trabaja

gen drop_trabaja=_n <= 6

gen sample_trabaja=(drop_trabaja==0)

keep if sample_trabaja==1

drop if (dia!=1 | condicion_==2)
ttest trabaja if universidad==1, by(baseline)
tab trabaja baseline if universidad==1, chi2

**diff within UAndes

ttest trabaja if universidad==0, by(baseline)
tab trabaja baseline if universidad==0, chi2

**diff within CONTROL
ttest trabaja if baseline==1, by(universidad)
tab trabaja universidad if baseline==1, chi2

**diff within TREATMENTS
ttest trabaja if baseline==0, by(universidad)
tab trabaja universidad if baseline==0, chi2
******************END TABLE E.2 ******************************************************

log close
